Description Usage
View source: R/theme_periodic.R
theme_periodic Sets up defaults for ggplots so I don't need to keep doing these over and over.
theme_periodic
1
theme_periodic()
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.